hanlders

package
v0.0.0-...-1d416a3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2023 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CreateReleaseHandler

type CreateReleaseHandler struct {
	// contains filtered or unexported fields
}

func NewCreateReleaseHandler

func NewCreateReleaseHandler() (*CreateReleaseHandler, error)

func (CreateReleaseHandler) CreateRelease

func (c CreateReleaseHandler) CreateRelease(applicationUpdateMessage models.ApplicationUpdateMessage) error

CreateRelease will attempt to create a release for up to two hours, which takes the standard maintenance window of a cloud hosted instanced into account.

Jump to