Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateReleaseHandler ¶
type CreateReleaseHandler struct {
// contains filtered or unexported fields
}
func NewCreateReleaseHandler ¶
func NewCreateReleaseHandler() (*CreateReleaseHandler, error)
func (CreateReleaseHandler) CreateRelease ¶
func (c CreateReleaseHandler) CreateRelease(applicationUpdateMessage models.ApplicationUpdateMessage) error
CreateRelease will attempt to create a release for up to two hours, which takes the standard maintenance window of a cloud hosted instanced into account.
Click to show internal directories.
Click to hide internal directories.